![Build Status](https://travis-ci.org/xpepermint/express-vue-builder.svg?branch=master)&nbsp;[![NPM Version](https://badge.fury.io/js/express-vue-builder.svg)](https://badge.fury.io/js/express-vue-builder)&nbsp;[![Dependency Status](https://gemnasium.com/xpepermint/express-vue-builder.svg)](https://gemnasium.com/xpepermint/express-vue-builder)

# [express](http://expressjs.com)-[vue-builder](https://github.com/xpepermint/vue-builder)

> Vue.js server-side and client-side rendering middleware for Express.js.

<img src="logo.png" height="60" style="margin-bottom: 20px" />

This package provides [Vue.js](http://vuejs.org) middlewares for [express.js](http://expressjs.com). It includes a development server for client-side rendering with support for hot module replacement and a server-side rendering utils.

This is an open source package for [Vue.js](http://vuejs.org/). The source code is available on [GitHub](https://github.com/xpepermint/express-vue-builder) where you can also find our [issue tracker](https://github.com/xpepermint/express-vue-builder/issues).

## Related Projects

* [vue-webpack](https://github.com/xpepermint/vue-webpack): Webpack configuration object generator for Vue.js.
* [vue-builder](https://github.com/xpepermint/express-vue-builder): Server-side and client-side rendering for Vue.js.

## Install

Run the command below to install the package.

```
$ npm install --save-dev express-vue-builder vue-builder webpack@2.1.0-beta.25
```

## Usage

```
const {build} = require('vue-webpack');
const {devServer, bundleRenderer} = require('../../../src');

```


```js
let app = express();
// include a production or a development middleware
app.use(isProduction ? vueBundleRenderer() : vueDevServer());
// render the application
```

Check the included `./example` directory for more or run the `npm run example:start` command from command-line.

## API

**VueBuilder(config)**

> Core class for building server-side and client-side bundles.

| Option | Type | Required | Default | Description
|--------|------|----------|---------|------------
| config | Object | Yes | - | Webpack configuration object.

**VueBuilder.prototype.build()**:Promise

> Returns a promise which saves application files to the destination folder.

**VueBuilder.prototype.compile()**:Promise

> Returns a promise which compiles the application bundle and returns the the source code as string.

**VueRender({source})**

> Core class for server-side application rendering.

| Option | Type | Required | Default | Description
|--------|------|----------|---------|------------
| source | String | Yes | - | Bundle source code.

**VueRender.prototype.renderToStream()**:Stream

> Renders the application and returns a stream.

**VueRender.prototype.renderToString()**:Promise

> Returns a promise which renders the application and returns a string.

## License (MIT)

```
Copyright (c) 2016 Kristijan Sedlak <xpepermint@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
```
